@@ -7,7 +7,6 @@ import sys
 import tempfile
 import shutil
 import traceback
-import pkg_resources
 from ._utils import has_grpcio_protoc, invoke_protoc, print_versions
 
 # Compatibility layer to make TemporaryDirectory() available on Python 2.
@@ -42,8 +41,7 @@ def build_nanopb_proto(protosrc, dirname):
     if has_grpcio_protoc():
         # grpcio-tools has an extra CLI argument
         # from grpc.tools.protoc __main__ invocation.
-        _builtin_proto_include = pkg_resources.resource_filename('grpc_tools', '_proto')
-        cmd.append("-I={}".format(_builtin_proto_include))
+        cmd.append("-I={}".format(_utils.get_grpc_tools_proto_path()))
 
     try:
         invoke_protoc(argv=cmd)
@@ -67,27 +65,28 @@ def load_nanopb_pb2():
     # If the value of the $NANOPB_PB2_TEMP_DIR exists as a directory, it is used instead
     # of system temp folder.
 
-    build_error = None
-    proto_ok = False
     tmpdir = os.getenv("NANOPB_PB2_TEMP_DIR")
     temporary_only = (tmpdir is not None)
     dirname = os.path.dirname(__file__)
     protosrc = os.path.join(dirname, "nanopb.proto")
     protodst = os.path.join(dirname, "nanopb_pb2.py")
-    proto_ok = False
 
     if tmpdir is not None and not os.path.isdir(tmpdir):
         tmpdir = None # Use system-wide temp dir
 
+    no_rebuild = bool(int(os.getenv("NANOPB_PB2_NO_REBUILD", default = 0)))
+    if bool(no_rebuild):
+        # Don't attempt to autogenerate nanopb_pb2.py, external build rules
+        # should have already done so.
+        import nanopb_pb2 as nanopb_pb2_mod
+        return nanopb_pb2_mod
+
     if os.path.isfile(protosrc):
         src_date = os.path.getmtime(protosrc)
-        if not os.path.isfile(protodst) or os.path.getmtime(protodst) < src_date:
-            # Outdated, rebuild
-            proto_ok = False
-        else:
+        if os.path.isfile(protodst) and os.path.getmtime(protodst) >= src_date:
             try:
                 from . import nanopb_pb2 as nanopb_pb2_mod
-                proto_ok = True
+                return nanopb_pb2_mod
             except Exception as e:
                 sys.stderr.write("Failed to import nanopb_pb2.py: " + str(e) + "\n"
                                 "Will automatically attempt to rebuild this.\n"
@@ -95,34 +94,33 @@ def load_nanopb_pb2():
                 print_versions()
 
     # Try to rebuild into generator/proto directory
-    if not proto_ok and not temporary_only:
-        proto_ok = build_nanopb_proto(protosrc, dirname)
+    if not temporary_only:
+        build_nanopb_proto(protosrc, dirname)
 
         try:
             from . import nanopb_pb2 as nanopb_pb2_mod
+            return nanopb_pb2_mod
         except:
             sys.stderr.write("Failed to import generator/proto/nanopb_pb2.py:\n")
             sys.stderr.write(traceback.format_exc() + "\n")
 
     # Try to rebuild into temporary directory
-    if not proto_ok:
-        with TemporaryDirectory(prefix = 'nanopb-', dir = tmpdir) as protodir:
-            proto_ok = build_nanopb_proto(protosrc, protodir)
+    with TemporaryDirectory(prefix = 'nanopb-', dir = tmpdir) as protodir:
+        build_nanopb_proto(protosrc, protodir)
 
-            if protodir not in sys.path:
-                sys.path.insert(0, protodir)
+        if protodir not in sys.path:
+            sys.path.insert(0, protodir)
 
-            try:
-                import nanopb_pb2 as nanopb_pb2_mod
-            except:
-                sys.stderr.write("Failed to import %s/nanopb_pb2.py:\n" % protodir)
-                sys.stderr.write(traceback.format_exc() + "\n")
+        try:
+            import nanopb_pb2 as nanopb_pb2_mod
+            return nanopb_pb2_mod
+        except:
+            sys.stderr.write("Failed to import %s/nanopb_pb2.py:\n" % protodir)
+            sys.stderr.write(traceback.format_exc() + "\n")
 
     # If everything fails
-    if not proto_ok:
-        sys.stderr.write("\n\nGenerating nanopb_pb2.py failed.\n")
-        sys.stderr.write("Make sure that a protoc generator is available and matches python-protobuf version.\n")
-        print_versions()
-        sys.exit(1)
+    sys.stderr.write("\n\nGenerating nanopb_pb2.py failed.\n")
+    sys.stderr.write("Make sure that a protoc generator is available and matches python-protobuf version.\n")
+    print_versions()
+    sys.exit(1)
 
-    return nanopb_pb2_mod
