@@ -39,8 +39,7 @@ bool check_alltypes(pb_istream_t *stream, int mode)
     TEST(alltypes.req_string    && strcmp(alltypes.req_string, "1014") == 0);
     TEST(alltypes.req_bytes     && alltypes.req_bytes->size == 4);
     TEST(alltypes.req_bytes     && memcmp(&alltypes.req_bytes->bytes, "1015", 4) == 0);
-    TEST(alltypes.req_submsg    && alltypes.req_submsg->substuff1
-                                && strcmp(alltypes.req_submsg->substuff1, "1016") == 0);
+    TEST(alltypes.req_submsg    && strcmp(alltypes.req_submsg->substuff1, "1016") == 0);
     TEST(alltypes.req_submsg    && alltypes.req_submsg->substuff2
                                 && *alltypes.req_submsg->substuff2 == 1016);
     TEST(alltypes.req_enum      && *alltypes.req_enum == MyEnum_Truth);
@@ -77,6 +76,7 @@ bool check_alltypes(pb_istream_t *stream, int mode)
     TEST(alltypes.rep_fbytes[0][0] == 0 && alltypes.rep_fbytes[0][3] == 0);
     TEST(memcmp(alltypes.rep_fbytes[4], "2019", 4) == 0);
     TEST(alltypes.rep_farray && (*alltypes.rep_farray)[0] == 0 && (*alltypes.rep_farray)[4] == 2040);
+    TEST(alltypes.rep_farray2 && (*alltypes.rep_farray2)[0] == 0 && (*alltypes.rep_farray2)[2] == 2095);
 
     if (mode == 0)
     {
