@@ -5,12 +5,14 @@ from platforms.stm32.stm32 import set_stm32_platform
 from platforms.avr.avr import set_avr_platform
 from platforms.mips.mips import set_mips_platform
 from platforms.mipsel.mipsel import set_mipsel_platform
+from platforms.riscv64.riscv64 import set_riscv64_platform
 
 platforms = {
     'STM32': set_stm32_platform,
     'AVR': set_avr_platform,
     'MIPS': set_mips_platform,
     'MIPSEL': set_mipsel_platform,
+    'RISCV64': set_riscv64_platform,
 }
 
 try:
@@ -20,25 +22,30 @@ try:
 except ImportError:
     pass
 
+# UTF-8 support on Python 2
+if sys.version_info.major == 2:
+    import codecs
+    open = codecs.open
+
 def add_nanopb_builders(env):
     '''Add the necessary builder commands for nanopb tests.'''
 
     # Build command that runs a test program and saves the output
     def run_test(target, source, env):
         if len(source) > 1:
-            infile = open(str(source[1]))
+            infile = open(str(source[1]), 'rb')
         else:
             infile = None
         
-        if env.has_key("COMMAND"):
+        if "COMMAND" in env:
             args = [env["COMMAND"]]
         else:
             args = [str(source[0])]
         
-        if env.has_key('ARGS'):
+        if 'ARGS' in env:
             args.extend(env['ARGS'])
 
-        if env.has_key("TEST_RUNNER"):
+        if "TEST_RUNNER" in env:
             args = [env["TEST_RUNNER"]] + args
         
         print('Command line: ' + str(args))
@@ -96,8 +103,8 @@ def add_nanopb_builders(env):
 
     # Build command that checks that each pattern in source2 is found in source1.
     def match_files(target, source, env):
-        data = open(str(source[0]), 'rU').read()
-        patterns = open(str(source[1]))
+        data = open(str(source[0]), 'r', encoding = 'utf-8').read()
+        patterns = open(str(source[1]), 'r', encoding = 'utf-8')
         for pattern in patterns:
             if pattern.strip():
                 invert = False
